@@ -17,7 +17,7 @@
 import dataclasses
 import json  # type: ignore
 import re
-from typing import Callable, Dict, List, Optional, Sequence, Tuple, Union
+from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
 import warnings
 
 from google.api_core import (
@@ -343,7 +343,7 @@ class AttachedClustersRestInterceptor:
         self,
         request: operations_pb2.CancelOperationRequest,
         metadata: Sequence[Tuple[str, str]],
-    ) -> None:
+    ) -> Tuple[operations_pb2.CancelOperationRequest, Sequence[Tuple[str, str]]]:
         """Pre-rpc interceptor for cancel_operation
 
         Override in a subclass to manipulate the request or metadata
@@ -351,9 +351,7 @@ class AttachedClustersRestInterceptor:
         """
         return request, metadata
 
-    def post_cancel_operation(
-        self, response: operations_pb2.CancelOperationRequest
-    ) -> None:
+    def post_cancel_operation(self, response: None) -> None:
         """Post-rpc interceptor for cancel_operation
 
         Override in a subclass to manipulate the response
@@ -366,7 +364,7 @@ class AttachedClustersRestInterceptor:
         self,
         request: operations_pb2.DeleteOperationRequest,
         metadata: Sequence[Tuple[str, str]],
-    ) -> None:
+    ) -> Tuple[operations_pb2.DeleteOperationRequest, Sequence[Tuple[str, str]]]:
         """Pre-rpc interceptor for delete_operation
 
         Override in a subclass to manipulate the request or metadata
@@ -374,9 +372,7 @@ class AttachedClustersRestInterceptor:
         """
         return request, metadata
 
-    def post_delete_operation(
-        self, response: operations_pb2.DeleteOperationRequest
-    ) -> None:
+    def post_delete_operation(self, response: None) -> None:
         """Post-rpc interceptor for delete_operation
 
         Override in a subclass to manipulate the response
@@ -389,7 +385,7 @@ class AttachedClustersRestInterceptor:
         self,
         request: operations_pb2.GetOperationRequest,
         metadata: Sequence[Tuple[str, str]],
-    ) -> operations_pb2.Operation:
+    ) -> Tuple[operations_pb2.GetOperationRequest, Sequence[Tuple[str, str]]]:
         """Pre-rpc interceptor for get_operation
 
         Override in a subclass to manipulate the request or metadata
@@ -398,7 +394,7 @@ class AttachedClustersRestInterceptor:
         return request, metadata
 
     def post_get_operation(
-        self, response: operations_pb2.GetOperationRequest
+        self, response: operations_pb2.Operation
     ) -> operations_pb2.Operation:
         """Post-rpc interceptor for get_operation
 
@@ -412,7 +408,7 @@ class AttachedClustersRestInterceptor:
         self,
         request: operations_pb2.ListOperationsRequest,
         metadata: Sequence[Tuple[str, str]],
-    ) -> operations_pb2.ListOperationsResponse:
+    ) -> Tuple[operations_pb2.ListOperationsRequest, Sequence[Tuple[str, str]]]:
         """Pre-rpc interceptor for list_operations
 
         Override in a subclass to manipulate the request or metadata
@@ -421,7 +417,7 @@ class AttachedClustersRestInterceptor:
         return request, metadata
 
     def post_list_operations(
-        self, response: operations_pb2.ListOperationsRequest
+        self, response: operations_pb2.ListOperationsResponse
     ) -> operations_pb2.ListOperationsResponse:
         """Post-rpc interceptor for list_operations
 
@@ -595,7 +591,7 @@ class AttachedClustersRestTransport(AttachedClustersTransport):
         def __hash__(self):
             return hash("CreateAttachedCluster")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {
             "attachedClusterId": "",
         }
 
@@ -621,7 +617,6 @@ class AttachedClustersRestTransport(AttachedClustersTransport):
                 request (~.attached_service.CreateAttachedClusterRequest):
                     The request object. Request message for
                 ``AttachedClusters.CreateAttachedCluster`` method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -695,7 +690,7 @@ class AttachedClustersRestTransport(AttachedClustersTransport):
         def __hash__(self):
             return hash("DeleteAttachedCluster")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -719,7 +714,6 @@ class AttachedClustersRestTransport(AttachedClustersTransport):
                 request (~.attached_service.DeleteAttachedClusterRequest):
                     The request object. Request message for
                 ``AttachedClusters.DeleteAttachedCluster`` method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -784,7 +778,7 @@ class AttachedClustersRestTransport(AttachedClustersTransport):
         def __hash__(self):
             return hash("GenerateAttachedClusterInstallManifest")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {
             "attachedClusterId": "",
             "platformVersion": "",
         }
@@ -813,7 +807,6 @@ class AttachedClustersRestTransport(AttachedClustersTransport):
                         The request object. Request message for
                     ``AttachedClusters.GenerateAttachedClusterInstallManifest``
                     method.
-
                     retry (google.api_core.retry.Retry): Designation of what errors, if any,
                         should be retried.
                     timeout (float): The timeout for this request.
@@ -891,7 +884,7 @@ class AttachedClustersRestTransport(AttachedClustersTransport):
         def __hash__(self):
             return hash("GetAttachedCluster")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -915,7 +908,6 @@ class AttachedClustersRestTransport(AttachedClustersTransport):
                 request (~.attached_service.GetAttachedClusterRequest):
                     The request object. Request message for
                 ``AttachedClusters.GetAttachedCluster`` method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -981,7 +973,7 @@ class AttachedClustersRestTransport(AttachedClustersTransport):
         def __hash__(self):
             return hash("GetAttachedServerConfig")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1006,7 +998,6 @@ class AttachedClustersRestTransport(AttachedClustersTransport):
                     request (~.attached_service.GetAttachedServerConfigRequest):
                         The request object. GetAttachedServerConfigRequest gets
                     the server config for attached clusters.
-
                     retry (google.api_core.retry.Retry): Designation of what errors, if any,
                         should be retried.
                     timeout (float): The timeout for this request.
@@ -1073,7 +1064,7 @@ class AttachedClustersRestTransport(AttachedClustersTransport):
         def __hash__(self):
             return hash("ImportAttachedCluster")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1097,7 +1088,6 @@ class AttachedClustersRestTransport(AttachedClustersTransport):
                 request (~.attached_service.ImportAttachedClusterRequest):
                     The request object. Request message for
                 ``AttachedClusters.ImportAttachedCluster`` method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1171,7 +1161,7 @@ class AttachedClustersRestTransport(AttachedClustersTransport):
         def __hash__(self):
             return hash("ListAttachedClusters")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1195,7 +1185,6 @@ class AttachedClustersRestTransport(AttachedClustersTransport):
                 request (~.attached_service.ListAttachedClustersRequest):
                     The request object. Request message for
                 ``AttachedClusters.ListAttachedClusters`` method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1261,7 +1250,7 @@ class AttachedClustersRestTransport(AttachedClustersTransport):
         def __hash__(self):
             return hash("UpdateAttachedCluster")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {
             "updateMask": {},
         }
 
@@ -1287,7 +1276,6 @@ class AttachedClustersRestTransport(AttachedClustersTransport):
                 request (~.attached_service.UpdateAttachedClusterRequest):
                     The request object. Request message for
                 ``AttachedClusters.UpdateAttachedCluster`` method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
