@@ -297,8 +297,8 @@ class AwsClustersAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.gke_multicloud_v1.types.CreateAwsClusterRequest, dict]]):
-                The request object. Request message for
-                `AwsClusters.CreateAwsCluster` method.
+                The request object. Request message for ``AwsClusters.CreateAwsCluster``
+                method.
             parent (:class:`str`):
                 Required. The parent location where this
                 [AwsCluster][google.cloud.gkemulticloud.v1.AwsCluster]
@@ -465,8 +465,8 @@ class AwsClustersAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.gke_multicloud_v1.types.UpdateAwsClusterRequest, dict]]):
-                The request object. Request message for
-                `AwsClusters.UpdateAwsCluster` method.
+                The request object. Request message for ``AwsClusters.UpdateAwsCluster``
+                method.
             aws_cluster (:class:`google.cloud.gke_multicloud_v1.types.AwsCluster`):
                 Required. The
                 [AwsCluster][google.cloud.gkemulticloud.v1.AwsCluster]
@@ -617,8 +617,8 @@ class AwsClustersAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.gke_multicloud_v1.types.GetAwsClusterRequest, dict]]):
-                The request object. Request message for
-                `AwsClusters.GetAwsCluster` method.
+                The request object. Request message for ``AwsClusters.GetAwsCluster``
+                method.
             name (:class:`str`):
                 Required. The name of the
                 [AwsCluster][google.cloud.gkemulticloud.v1.AwsCluster]
@@ -737,8 +737,8 @@ class AwsClustersAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.gke_multicloud_v1.types.ListAwsClustersRequest, dict]]):
-                The request object. Request message for
-                `AwsClusters.ListAwsClusters` method.
+                The request object. Request message for ``AwsClusters.ListAwsClusters``
+                method.
             parent (:class:`str`):
                 Required. The parent location which owns this collection
                 of
@@ -882,8 +882,8 @@ class AwsClustersAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.gke_multicloud_v1.types.DeleteAwsClusterRequest, dict]]):
-                The request object. Request message for
-                `AwsClusters.DeleteAwsCluster` method.
+                The request object. Request message for ``AwsClusters.DeleteAwsCluster``
+                method.
             name (:class:`str`):
                 Required. The resource name the
                 [AwsCluster][google.cloud.gkemulticloud.v1.AwsCluster]
@@ -1014,7 +1014,7 @@ class AwsClustersAsyncClient:
         Args:
             request (Optional[Union[google.cloud.gke_multicloud_v1.types.GenerateAwsAccessTokenRequest, dict]]):
                 The request object. Request message for
-                `AwsClusters.GenerateAwsAccessToken` method.
+                ``AwsClusters.GenerateAwsAccessToken`` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1129,8 +1129,8 @@ class AwsClustersAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.gke_multicloud_v1.types.CreateAwsNodePoolRequest, dict]]):
-                The request object. Response message for
-                `AwsClusters.CreateAwsNodePool` method.
+                The request object. Response message for ``AwsClusters.CreateAwsNodePool``
+                method.
             parent (:class:`str`):
                 Required. The
                 [AwsCluster][google.cloud.gkemulticloud.v1.AwsCluster]
@@ -1292,8 +1292,8 @@ class AwsClustersAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.gke_multicloud_v1.types.UpdateAwsNodePoolRequest, dict]]):
-                The request object. Request message for
-                `AwsClusters.UpdateAwsNodePool` method.
+                The request object. Request message for ``AwsClusters.UpdateAwsNodePool``
+                method.
             aws_node_pool (:class:`google.cloud.gke_multicloud_v1.types.AwsNodePool`):
                 Required. The
                 [AwsNodePool][google.cloud.gkemulticloud.v1.AwsNodePool]
@@ -1444,8 +1444,8 @@ class AwsClustersAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.gke_multicloud_v1.types.GetAwsNodePoolRequest, dict]]):
-                The request object. Request message for
-                `AwsClusters.GetAwsNodePool` method.
+                The request object. Request message for ``AwsClusters.GetAwsNodePool``
+                method.
             name (:class:`str`):
                 Required. The name of the
                 [AwsNodePool][google.cloud.gkemulticloud.v1.AwsNodePool]
@@ -1565,8 +1565,8 @@ class AwsClustersAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.gke_multicloud_v1.types.ListAwsNodePoolsRequest, dict]]):
-                The request object. Request message for
-                `AwsClusters.ListAwsNodePools` method.
+                The request object. Request message for ``AwsClusters.ListAwsNodePools``
+                method.
             parent (:class:`str`):
                 Required. The parent ``AwsCluster`` which owns this
                 collection of
@@ -1707,8 +1707,8 @@ class AwsClustersAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.gke_multicloud_v1.types.DeleteAwsNodePoolRequest, dict]]):
-                The request object. Request message for
-                `AwsClusters.DeleteAwsNodePool` method.
+                The request object. Request message for ``AwsClusters.DeleteAwsNodePool``
+                method.
             name (:class:`str`):
                 Required. The resource name the
                 [AwsNodePool][google.cloud.gkemulticloud.v1.AwsNodePool]
