@@ -17,7 +17,7 @@
 import dataclasses
 import json  # type: ignore
 import re
-from typing import Callable, Dict, List, Optional, Sequence, Tuple, Union
+from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
 import warnings
 
 from google.api_core import (
@@ -454,7 +454,7 @@ class AwsClustersRestInterceptor:
         self,
         request: operations_pb2.CancelOperationRequest,
         metadata: Sequence[Tuple[str, str]],
-    ) -> None:
+    ) -> Tuple[operations_pb2.CancelOperationRequest, Sequence[Tuple[str, str]]]:
         """Pre-rpc interceptor for cancel_operation
 
         Override in a subclass to manipulate the request or metadata
@@ -462,9 +462,7 @@ class AwsClustersRestInterceptor:
         """
         return request, metadata
 
-    def post_cancel_operation(
-        self, response: operations_pb2.CancelOperationRequest
-    ) -> None:
+    def post_cancel_operation(self, response: None) -> None:
         """Post-rpc interceptor for cancel_operation
 
         Override in a subclass to manipulate the response
@@ -477,7 +475,7 @@ class AwsClustersRestInterceptor:
         self,
         request: operations_pb2.DeleteOperationRequest,
         metadata: Sequence[Tuple[str, str]],
-    ) -> None:
+    ) -> Tuple[operations_pb2.DeleteOperationRequest, Sequence[Tuple[str, str]]]:
         """Pre-rpc interceptor for delete_operation
 
         Override in a subclass to manipulate the request or metadata
@@ -485,9 +483,7 @@ class AwsClustersRestInterceptor:
         """
         return request, metadata
 
-    def post_delete_operation(
-        self, response: operations_pb2.DeleteOperationRequest
-    ) -> None:
+    def post_delete_operation(self, response: None) -> None:
         """Post-rpc interceptor for delete_operation
 
         Override in a subclass to manipulate the response
@@ -500,7 +496,7 @@ class AwsClustersRestInterceptor:
         self,
         request: operations_pb2.GetOperationRequest,
         metadata: Sequence[Tuple[str, str]],
-    ) -> operations_pb2.Operation:
+    ) -> Tuple[operations_pb2.GetOperationRequest, Sequence[Tuple[str, str]]]:
         """Pre-rpc interceptor for get_operation
 
         Override in a subclass to manipulate the request or metadata
@@ -509,7 +505,7 @@ class AwsClustersRestInterceptor:
         return request, metadata
 
     def post_get_operation(
-        self, response: operations_pb2.GetOperationRequest
+        self, response: operations_pb2.Operation
     ) -> operations_pb2.Operation:
         """Post-rpc interceptor for get_operation
 
@@ -523,7 +519,7 @@ class AwsClustersRestInterceptor:
         self,
         request: operations_pb2.ListOperationsRequest,
         metadata: Sequence[Tuple[str, str]],
-    ) -> operations_pb2.ListOperationsResponse:
+    ) -> Tuple[operations_pb2.ListOperationsRequest, Sequence[Tuple[str, str]]]:
         """Pre-rpc interceptor for list_operations
 
         Override in a subclass to manipulate the request or metadata
@@ -532,7 +528,7 @@ class AwsClustersRestInterceptor:
         return request, metadata
 
     def post_list_operations(
-        self, response: operations_pb2.ListOperationsRequest
+        self, response: operations_pb2.ListOperationsResponse
     ) -> operations_pb2.ListOperationsResponse:
         """Post-rpc interceptor for list_operations
 
@@ -706,7 +702,7 @@ class AwsClustersRestTransport(AwsClustersTransport):
         def __hash__(self):
             return hash("CreateAwsCluster")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {
             "awsClusterId": "",
         }
 
@@ -732,7 +728,6 @@ class AwsClustersRestTransport(AwsClustersTransport):
                 request (~.aws_service.CreateAwsClusterRequest):
                     The request object. Request message for ``AwsClusters.CreateAwsCluster``
                 method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -806,7 +801,7 @@ class AwsClustersRestTransport(AwsClustersTransport):
         def __hash__(self):
             return hash("CreateAwsNodePool")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {
             "awsNodePoolId": "",
         }
 
@@ -832,7 +827,6 @@ class AwsClustersRestTransport(AwsClustersTransport):
                 request (~.aws_service.CreateAwsNodePoolRequest):
                     The request object. Response message for ``AwsClusters.CreateAwsNodePool``
                 method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -906,7 +900,7 @@ class AwsClustersRestTransport(AwsClustersTransport):
         def __hash__(self):
             return hash("DeleteAwsCluster")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -930,7 +924,6 @@ class AwsClustersRestTransport(AwsClustersTransport):
                 request (~.aws_service.DeleteAwsClusterRequest):
                     The request object. Request message for ``AwsClusters.DeleteAwsCluster``
                 method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -995,7 +988,7 @@ class AwsClustersRestTransport(AwsClustersTransport):
         def __hash__(self):
             return hash("DeleteAwsNodePool")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1019,7 +1012,6 @@ class AwsClustersRestTransport(AwsClustersTransport):
                 request (~.aws_service.DeleteAwsNodePoolRequest):
                     The request object. Request message for ``AwsClusters.DeleteAwsNodePool``
                 method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1084,7 +1076,7 @@ class AwsClustersRestTransport(AwsClustersTransport):
         def __hash__(self):
             return hash("GenerateAwsAccessToken")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1108,7 +1100,6 @@ class AwsClustersRestTransport(AwsClustersTransport):
                 request (~.aws_service.GenerateAwsAccessTokenRequest):
                     The request object. Request message for
                 ``AwsClusters.GenerateAwsAccessToken`` method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1174,7 +1165,7 @@ class AwsClustersRestTransport(AwsClustersTransport):
         def __hash__(self):
             return hash("GetAwsCluster")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1198,7 +1189,6 @@ class AwsClustersRestTransport(AwsClustersTransport):
                 request (~.aws_service.GetAwsClusterRequest):
                     The request object. Request message for ``AwsClusters.GetAwsCluster``
                 method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1260,7 +1250,7 @@ class AwsClustersRestTransport(AwsClustersTransport):
         def __hash__(self):
             return hash("GetAwsNodePool")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1284,7 +1274,6 @@ class AwsClustersRestTransport(AwsClustersTransport):
                 request (~.aws_service.GetAwsNodePoolRequest):
                     The request object. Request message for ``AwsClusters.GetAwsNodePool``
                 method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1348,7 +1337,7 @@ class AwsClustersRestTransport(AwsClustersTransport):
         def __hash__(self):
             return hash("GetAwsServerConfig")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1372,7 +1361,6 @@ class AwsClustersRestTransport(AwsClustersTransport):
                 request (~.aws_service.GetAwsServerConfigRequest):
                     The request object. GetAwsServerConfigRequest gets the
                 server config of GKE cluster on AWS.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1438,7 +1426,7 @@ class AwsClustersRestTransport(AwsClustersTransport):
         def __hash__(self):
             return hash("ListAwsClusters")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1462,7 +1450,6 @@ class AwsClustersRestTransport(AwsClustersTransport):
                 request (~.aws_service.ListAwsClustersRequest):
                     The request object. Request message for ``AwsClusters.ListAwsClusters``
                 method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1528,7 +1515,7 @@ class AwsClustersRestTransport(AwsClustersTransport):
         def __hash__(self):
             return hash("ListAwsNodePools")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1552,7 +1539,6 @@ class AwsClustersRestTransport(AwsClustersTransport):
                 request (~.aws_service.ListAwsNodePoolsRequest):
                     The request object. Request message for ``AwsClusters.ListAwsNodePools``
                 method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1618,7 +1604,7 @@ class AwsClustersRestTransport(AwsClustersTransport):
         def __hash__(self):
             return hash("UpdateAwsCluster")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {
             "updateMask": {},
         }
 
@@ -1644,7 +1630,6 @@ class AwsClustersRestTransport(AwsClustersTransport):
                 request (~.aws_service.UpdateAwsClusterRequest):
                     The request object. Request message for ``AwsClusters.UpdateAwsCluster``
                 method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1718,7 +1703,7 @@ class AwsClustersRestTransport(AwsClustersTransport):
         def __hash__(self):
             return hash("UpdateAwsNodePool")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {
             "updateMask": {},
         }
 
@@ -1744,7 +1729,6 @@ class AwsClustersRestTransport(AwsClustersTransport):
                 request (~.aws_service.UpdateAwsNodePoolRequest):
                     The request object. Request message for ``AwsClusters.UpdateAwsNodePool``
                 method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
